package com.sun.org.apache.xml.internal.security.transforms;

import com.sun.org.slf4j.internal.LoggerFactory;
import com.sun.org.slf4j.internal.Logger;

final class ClassLoaderUtils
{
    private static final Logger LOG;
    
    private ClassLoaderUtils() {
    }
    
    static Class<?> loadClass(String name, Class<?> clazz) throws ClassNotFoundException {
        try {
            ClassLoader contextClassLoader = Thread.currentThread().getContextClassLoader();
            if (contextClassLoader != null) {
                return contextClassLoader.loadClass(name);
            }
        }
        catch (ClassNotFoundException e) {
            ClassLoaderUtils.LOG.debug(e.getMessage(), e);
        }
        return loadClass2(name, clazz);
    }
    
    private static Class<?> loadClass2(String name, Class<?> clazz) throws ClassNotFoundException {
        try {
            return Class.forName(name);
        }
        catch (ClassNotFoundException e) {
            try {
                if (ClassLoaderUtils.class.getClassLoader() != null) {
                    return ClassLoaderUtils.class.getClassLoader().loadClass(name);
                }
            }
            catch (ClassNotFoundException ex) {
                if (clazz != null && clazz.getClassLoader() != null) {
                    return clazz.getClassLoader().loadClass(name);
                }
            }
            ClassLoaderUtils.LOG.debug(e.getMessage(), e);
            throw e;
        }
    }
    
    static {
        LOG = LoggerFactory.getLogger(ClassLoaderUtils.class);
    }
}
